@@ -26,7 +26,7 @@ double art::gaussain_sigma;
 
 int main(int argc, char* argv[]){
     cout << "=============================================================================="<<endl;
-    cout << "                            ART (Q Version 1.3.6)                             "<<endl; 
+    cout << "                            ART (Q Version 1.5.0)                             "<<endl; 
     cout << "   Copyright(c) 2008-2012, Weichun Huang, Jason Myers. All Rights Reserved.   "<<endl; 
     cout << "=============================================================================="<<endl<<endl;
 
@@ -57,6 +57,8 @@ int main(int argc, char* argv[]){
     bool rate_flag = false;
     bool first_qual = false;
     bool second_qual = false;
+    bool no_ALN = false;
+    unsigned int rand_seed = 0;
 
     // Command-line Arguments
     string suffID=""; 
@@ -170,6 +172,11 @@ int main(int argc, char* argv[]){
             } else if(!strcmp(arg, "--id") || !strcmp(arg, "-d")){
 		i++;
 		suffID = argv[i];
+            } else if(!strcmp(arg, "--noALN") || !strcmp(arg, "-na")){ 
+		no_ALN = true;
+            } else if(!strcmp(arg, "--rndSeed") || !strcmp(arg, "-rs")){
+		i++;
+		rand_seed = abs(atoi(argv[i]));
             } else {
 		arg_success = false;
 		cerr << "Fatal Error: " << arg << ", is not a valid parameter." << endl;
@@ -233,19 +240,18 @@ int main(int argc, char* argv[]){
 
 	cout << " Parameters" << endl << endl;
 	cout << "  -sam --samout   indicate to generate SAM alignment file" << endl;
-	cout << "  -sp  --sepProf  indicate the use of separate quality profiles for different bases (ATGC)" << endl << endl;
+	cout << "  -sp  --sepProf  indicate the use of separate quality profiles for different bases (ATGC)" << endl;
 	cout << "  -mp  --matepair indicate a mate-pair read simulation" << endl;
 	cout << "  -p   --paired   indicate a paired-end read simulation" << endl;
-	cout << "       NOTE: art will automatically switch to a mate-pair read simulation if the given mean fragment size >= 2000"<<endl<<endl;
-	cout << "  -q   --quiet    turn off end of run summary" << endl;
-	cout << "  -h   --help     print out usage information for ART" << endl<<endl;
-
+       	cout << "       NOTE: art will automatically switch to a mate-pair read simulation if the given mean fragment size >= 2000"<<endl;
 	cout << "  -i   --in       the filename of input DNA reference" << endl;
 	cout << "  -o   --out      the prefix of output files" << endl;
 	cout << "  -l   --len      the length of reads to be simulated" << endl;
 	cout << "  -f   --fcov     the fold of read coverage to be simulated" << endl;
 	cout << "  -m   --mflen    the mean size of DNA fragments for paired-end simulations" << endl;
 	cout << "  -s   --sdev     the standard deviation of DNA fragment size for paired-end simulations." << endl;
+	cout << "  -na  --noALN    do not output ALN alignment file" << endl;
+	cout << "  -rs  --rndSend  the seed for random number generator (default: system time in second)"  << endl;
 	cout << "  -ir  --insRate  the first-read insertion rate (default: 0.00009)"<< endl;
 	cout << "  -dr  --delRate  the first-read deletion rate (default:  0.00011)" << endl;
 	cout << "  -ir2 --insRate2 the second-read insertion rate (default: 0.00015)" << endl;
@@ -255,6 +261,8 @@ int main(int argc, char* argv[]){
 	cout << "  -1   --qprof1   the first-read quality profile" << endl;
 	cout << "  -2   --qprof2   the second-read quality profile" << endl;
 	cout << "  -d   --id       the prefix identification tag for read ID" << endl << endl;
+	cout << "  -q   --quiet    turn off end of run summary" << endl;
+	cout << "  -h   --help     print out usage information for ART" << endl<<endl;
 
 	cout << "****NOTES****" << endl;
 	cout << "* The default quality score profiles are determined based on the length" << endl; 
@@ -269,6 +277,11 @@ int main(int argc, char* argv[]){
 	exit(0);
     }
 
+    if(rand_seed==0){
+	    rand_seed=(unsigned int) time(NULL); 
+    }
+    srand (rand_seed);
+
     string seqfasta=out_file_prefix+num+".fa";
     string qualfasta=out_file_prefix+num+".qual";
     string alnfasta=out_file_prefix+num+".aln";
@@ -283,11 +296,12 @@ int main(int argc, char* argv[]){
 
     ofstream FQFILE(fqfile.c_str(),ios::binary);
     if(!FQFILE.is_open()) { cerr<<"Can not open output file: "<<fqfile<<endl; exit(0); }
-
-    ofstream ALNFILE(alnfasta.c_str(),ios::binary);
-    if(!ALNFILE.is_open()) { cerr<<"Can not open output file: "<<alnfasta<<endl; exit(0); }
-    ALNFILE<<"##ART_Illumina\tread_length\t"<<read_len<<endl;
-
+	ofstream ALNFILE;	
+	if (!no_ALN) {
+	       	ALNFILE.open(alnfasta.c_str(),ios::binary);
+	       	if(!ALNFILE.is_open()) { cerr<<"Can not open output file: "<<alnfasta<<endl; exit(0); }
+	       	ALNFILE<<"##ART_Illumina\tread_length\t"<<read_len<<endl;
+	}	
     empdist::set_err_prob();
     empdist qdist(qual_file1, qual_file2, sep_flag, read_len);
     int profile_size=qdist.qual_dist_first.size();
@@ -395,8 +409,10 @@ int main(int argc, char* argv[]){
     sH.getRefseqID(seq_file);
     sH.ID="01";
     sH.PN="ART_Illumina"; 
-    for(int i=0;i < argc; ++i) { sH.CL.append(argv[i]);sH.CL.append(" "); }
-    sH.printAlnHeader(ALNFILE);
+    if (!no_ALN){
+	    for(int i=0;i < argc; ++i) { sH.CL.append(argv[i]);sH.CL.append(" "); }
+	    sH.printAlnHeader(ALNFILE);
+    }
 
     if(sam_out){
 	    sH.printHeader(SAMFILE);
@@ -438,11 +454,13 @@ int main(int argc, char* argv[]){
 
         ofstream FQFILE2(fqfile2.c_str(),ios::binary);
         if(!FQFILE2.is_open()) { cerr<<"Can not open output file: "<<fqfile2<<endl; exit(0); }
-
-        ofstream ALNFILE2(alnfasta2.c_str(),ios::binary);
-        if(!ALNFILE2.is_open()) { cerr<<"Can not open output file: "<<alnfasta2<<endl; exit(0); }
-       	ALNFILE2<<"##ART_Illumina\tread_length\t"<<read_len<<endl;
-       	sH.printAlnHeader(ALNFILE2);
+       	ofstream ALNFILE2;
+       	if (!no_ALN) {
+	       	ALNFILE2.open(alnfasta2.c_str(),ios::binary);
+	       	if(!ALNFILE2.is_open()) { cerr<<"Can not open output file: "<<alnfasta2<<endl; exit(0); }
+	       	ALNFILE2<<"##ART_Illumina\tread_length\t"<<read_len<<endl;
+	       	sH.printAlnHeader(ALNFILE2);
+       	}
 
         seqRead a_read_2;
         a_read_2.set_rate(read_len,insRate2,2,a_read.ins_rate);
@@ -469,7 +487,7 @@ int main(int argc, char* argv[]){
                 a_read_2.clear();
                 //a_art.next_read(a_read);
 		if(is_matepair){
-		       	a_art.next_pair_read_indel(a_read, a_read_2); 
+		       	a_art.next_pair_read_indel_mate(a_read, a_read_2); 
 		}
 		else{
 		       	a_art.next_pair_read_indel_cmp(a_read, a_read_2); 
@@ -505,8 +523,8 @@ int main(int argc, char* argv[]){
                 a_read.add_error(qual);
                 a_read_2.add_error(qual_2);
 		srID=read_id;
-                read_id_2=read_id+"-2";
-                read_id+="-1";
+                read_id_2=read_id+"/2";
+                read_id+="/1";
 
                 FQFILE<<"@"<<read_id<<endl<<a_read.seq_read<<endl<<"+"<<endl;
                 for(size_t k=0; k<qual.size(); k++){
@@ -514,29 +532,32 @@ int main(int argc, char* argv[]){
                 }
                 FQFILE<<endl;
 
-                ALNFILE<<">"<<id<<"\t"<<read_id<<"-1\t"<<a_read.bpos;
-                if(a_read.is_plus_strand) ALNFILE<<"\t+\n";
-                else ALNFILE<<"\t-\n";
-                if(! a_read.get_aln(aln_read,aln_ref)){
-                    aln_ref=a_read.seq_ref;
-		    aln_read=a_read.seq_read;
-                }
-                ALNFILE<<aln_ref<<endl<<aln_read<<endl;
+		if (!no_ALN) {
+		       	ALNFILE<<">"<<id<<"\t"<<read_id<<"-1\t"<<a_read.bpos;
+		       	if(a_read.is_plus_strand) ALNFILE<<"\t+\n";
+		       	else ALNFILE<<"\t-\n";
+		       	if(! a_read.get_aln(aln_read,aln_ref)){
+			       	aln_ref=a_read.seq_ref;
+			       	aln_read=a_read.seq_read;
+		       	}
+		       	ALNFILE<<aln_ref<<endl<<aln_read<<endl;
+	       	}
 
                 FQFILE2<<"@"<<read_id_2<<endl<<a_read_2.seq_read<<endl<<"+"<<endl;
                 for(size_t k=0; k<qual_2.size(); k++){
                     FQFILE2<<(char)(qual_2[k]+33);
                 }
                 FQFILE2<<endl;
-
-                ALNFILE2<<">"<<id<<"\t"<<read_id_2<<"\t"<<a_read_2.bpos;
-                if(a_read_2.is_plus_strand) ALNFILE2<<"\t+\n";
-                else ALNFILE2<<"\t-\n";
-                if(! a_read_2.get_aln(aln_read_2,aln_ref_2)){
-                    aln_ref_2=a_read_2.seq_ref;
-		    aln_read_2=a_read_2.seq_read;
-                }
-                ALNFILE2<<aln_ref_2<<endl<<aln_read_2<<endl;
+	       	if (!no_ALN) { 
+			ALNFILE2<<">"<<id<<"\t"<<read_id_2<<"\t"<<a_read_2.bpos;
+		       	if(a_read_2.is_plus_strand) ALNFILE2<<"\t+\n";
+		       	else ALNFILE2<<"\t-\n";
+		       	if(! a_read_2.get_aln(aln_read_2,aln_ref_2)){
+			       	aln_ref_2=a_read_2.seq_ref;
+			       	aln_read_2=a_read_2.seq_read;
+		       	}
+		       	ALNFILE2<<aln_ref_2<<endl<<aln_read_2<<endl;
+	       	}
 
 		if(sam_out){
 		       	sR.qname=srID;
@@ -560,29 +581,18 @@ int main(int argc, char* argv[]){
 			sR.flag=0x01 | 0x02 | 0x40;
 		       	sR2.flag=0x01 | 0x02 | 0x80;
 		       	if(a_read.is_plus_strand){
-			       	sR.pos=a_read.bpos+1;
-			       	if(! is_matepair){
+				       	sR.pos=a_read.bpos+1;
 				       	sR.flag =sR.flag | 0x20;
 				       	sR2.flag =sR2.flag |0x10;
 				       	sR2.pos=a_art.ref_seq.size()-(a_read_2.bpos+read_len-1);
 					sR2.reverse_comp();
-			       	}
-			       	else{
-				       	sR2.pos=a_read_2.bpos+1;
-			       	}
 		       	}
 		       	else{
-			       	sR.flag =sR.flag | 0x10;
-			       	sR.pos=a_art.ref_seq.size()-(a_read.bpos+read_len-1);
-			       	sR.reverse_comp();
-			       	if(is_matepair){
-				       	sR2.flag =sR2.flag | 0x10;
-				       	sR2.pos=a_art.ref_seq.size()-(a_read_2.bpos+read_len-1);
-				       	sR2.reverse_comp();
-				}
-				else{
+				       	sR.pos=a_art.ref_seq.size()-(a_read.bpos+read_len-1);
+				       	sR.reverse_comp();
 				       	sR2.pos=a_read_2.bpos+1;
-				}
+				       	sR.flag = sR.flag | 0x10;
+				       	sR2.flag = sR2.flag | 0x20;
 		       	}
 		       	sR.getCigar(aln_ref,aln_read);
 			sR2.getCigar(aln_ref_2,aln_read_2);
@@ -604,7 +614,7 @@ int main(int argc, char* argv[]){
             }
         }
         FQFILE2.close();
-        ALNFILE2.close();
+       	if (!no_ALN) ALNFILE2.close();
     }
     else{
         while(seq_reader.next_seq(id,a_art.ref_seq)){
@@ -648,15 +658,17 @@ int main(int argc, char* argv[]){
                     FQFILE<<(char)(qual[k]+33);
                 }
                 FQFILE<<endl;
-                ALNFILE<<">"<<id<<"\t"<<read_id<<"\t"<<a_read.bpos;
-                if(a_read.is_plus_strand) ALNFILE<<"\t+\n";
-                else ALNFILE<<"\t-\n";
+	       	if (!no_ALN) {
+		       	ALNFILE<<">"<<id<<"\t"<<read_id<<"\t"<<a_read.bpos;
+		       	if(a_read.is_plus_strand) ALNFILE<<"\t+\n";
+		       	else ALNFILE<<"\t-\n";
 
-                if(! a_read.get_aln(aln_read,aln_ref)){
-                    aln_ref=a_read.seq_ref;
-		    aln_read=a_read.seq_read;
-                }
-                ALNFILE<<aln_ref<<endl<<aln_read<<endl;
+			if(! a_read.get_aln(aln_read,aln_ref)){
+			       	aln_ref=a_read.seq_ref;
+			       	aln_read=a_read.seq_read;
+		       	}
+		       	ALNFILE<<aln_ref<<endl<<aln_read<<endl;
+	       	}
 
 		if(sam_out){
 		       	sR.qname=read_id;
@@ -688,13 +700,13 @@ int main(int argc, char* argv[]){
     }
 
     FQFILE.close();
-    ALNFILE.close();
-    if(sam_out){
-	    SAMFILE.close();
-    }
+    if (!no_ALN) { ALNFILE.close(); }
+    if(sam_out){ SAMFILE.close(); }
 
     if(!is_pairend_read){
         cout << "                          Single-end Simulation" << endl << endl;
+    } else if(is_matepair) {
+        cout << "                          MatePair-end Simulation" << endl << endl;
     } else {
         cout << "                          Paired-end Simulation" << endl << endl;
     }
@@ -702,6 +714,7 @@ int main(int argc, char* argv[]){
     end = clock();
     cpu_time_used = ((double) (end - start)) / CLOCKS_PER_SEC;
     cout<< "Total CPU time used: "<< cpu_time_used<<endl<<endl;
+    cout<< "The random seed for the run: "<< rand_seed<<endl<<endl;
 
     if(!show_flag){
 
@@ -756,14 +769,18 @@ int main(int argc, char* argv[]){
 	    cout << "  FASTQ Sequence Files:" << endl; 
 	    cout << "\t the 1st reads: " << fqfile << endl;
 	    cout << "\t the 2nd reads: " << fqfile2 << endl << endl;
-	    cout << "  ALN Alignment Files:" << endl; 
-	    cout << "\t the 1st reads: " << alnfasta << endl;
-	    cout << "\t the 2nd reads: " << alnfasta2 << endl << endl;;
+	    if(!no_ALN){
+		    cout << "  ALN Alignment Files:" << endl; 
+		    cout << "\t the 1st reads: " << alnfasta << endl;
+		    cout << "\t the 2nd reads: " << alnfasta2 << endl << endl;;
+	    }
 	} else {
 	    cout << "  FASTQ Sequence File:" << endl; 
 	    cout << "\t" << fqfile << endl << endl;
-	    cout << "  ALN Alignment File:" << endl; 
-	    cout << "\t" << alnfasta << endl << endl;
+	    if (!no_ALN){
+		    cout << "  ALN Alignment File:" << endl; 
+		    cout << "\t" << alnfasta << endl << endl;
+	    }
 	}
 	if(sam_out){
 	    cout << "  SAM Alignment File:" << endl; 
