@@ -101,7 +101,7 @@ empdist::empdist(string file_name, string file_name1, bool sep_qual, int length)
         read_emp_dist(file_name, true);
         read_emp_dist(file_name1, false);
     }
-    srand ( (unsigned int)time(NULL) );
+//    srand ( (unsigned int)time(NULL) );
 }
 
 //generate quali vector from dist of one read from pair-end [default first read]
@@ -158,19 +158,19 @@ bool empdist::get_read_qual_1st(string seq, vector<short>& read_qual){
     map <unsigned int, unsigned short>::iterator it;
     for(int i=0; i<len; i++){
         cumCC=(unsigned int) ceil(r_prob()*max_dist_number);
-	if(seq[i]=='a'){
+	if(seq[i]=='A'){
 	       	it=a_qual_dist_first[i].lower_bound(cumCC);
 	       	read_qual.push_back(it->second);
 	}
-	else if(seq[i]=='c'){
+	else if(seq[i]=='C'){
 	       	it=c_qual_dist_first[i].lower_bound(cumCC);
 	       	read_qual.push_back(it->second);
 	}
-	else if(seq[i]=='g'){
+	else if(seq[i]=='G'){
 	       	it=g_qual_dist_first[i].lower_bound(cumCC);
 	       	read_qual.push_back(it->second);
 	}
-	else if(seq[i]=='t'){
+	else if(seq[i]=='T'){
 	       	it=g_qual_dist_first[i].lower_bound(cumCC);
 	       	read_qual.push_back(it->second);
 	}
@@ -194,19 +194,19 @@ bool empdist::get_read_qual_2nd(string seq, vector<short>& read_qual){
     map <unsigned int, unsigned short>::iterator it;
     for(int i=0; i<len; i++){
         cumCC=(unsigned int) ceil(r_prob()*max_dist_number);
-	if(seq[i]=='a'){
+	if(seq[i]=='A'){
 	       	it=a_qual_dist_second[i].lower_bound(cumCC);
 	       	read_qual.push_back(it->second);
 	}
-	else if(seq[i]=='c'){
+	else if(seq[i]=='C'){
 	       	it=c_qual_dist_second[i].lower_bound(cumCC);
 	       	read_qual.push_back(it->second);
 	}
-	else if(seq[i]=='g'){
+	else if(seq[i]=='G'){
 	       	it=g_qual_dist_second[i].lower_bound(cumCC);
 	       	read_qual.push_back(it->second);
 	}
-	else if(seq[i]=='t'){
+	else if(seq[i]=='T'){
 	       	it=g_qual_dist_second[i].lower_bound(cumCC);
 	       	read_qual.push_back(it->second);
 	}
